<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\User;
use App\FechaVotaciones;
use App\TipoDocumento;
use App\Role;
use App\Carrera;
use App\ConcejoDirectivo;
use App\CandidatoDocente;
use App\Candidato;
use App\RegistroPosultacion;

class AdministradorController extends Controller
{
    

    public function __construct(){


        $this->middleware("Administrador");

    }
//Vistas
//administrador
    public function index(){

        return view("administrador.administrador");

    }

    public function postular(){

        $candidatos = User::where("role_id","!=",1)->where("id","!=",41)->get();
        $concejos = ConcejoDirectivo::all();
        return view("administrador.postular",compact("candidatos","concejos"));

    }
    public function guardarPostulacion(Request $request){

        date_default_timezone_set('America/Bogota');
        $fechaActual = explode("/",date("Y-m-d H:i:s"));
        $ultimaFecha = FechaVotaciones::orderByDesc("id")->first();

        if($fechaActual[0] > $ultimaFecha["fechaFinal"]){
            $mensajeError = "La fecha de postulaciones ya expiro, por favor establezca una fecha nueva";
            return view("administrador.administrador",compact("mensajeError"));
        }

        $cantidad = RegistroPosultacion::where("user_id",$request->user_id)->where("concejo_directivo_id",$request->concejo_directivo_id)->get();   
        $postulaciones = Candidato::where("user_id",$request->user_id)->where("concejo_directivo_id",$request->concejo_directivo_id)->get();
        $candidato = Candidato::where("user_id",$request->user_id)
        ->where("concejo_directivo_id",$request->concejo_directivo_id)
        ->where("fecha_votacione_id",$ultimaFecha["id"])
        ->get();
        
        if (count($candidato)>0) {
            $mensajeError = "El candidato ya se encuentra postulado en ese concejo directivo";
            return view("administrador.administrador",compact("mensajeError")); 
        }else{
            Candidato::create([
                    "user_id" => $request->user_id,
                    "concejo_directivo_id" => $request->concejo_directivo_id,
                    "fecha_votacione_id" => $ultimaFecha["id"],
                    "votos" => 0
            ]);

            if (count($cantidad)>0) {
                RegistroPosultacion::where("user_id",$request->user_id)->where("concejo_directivo_id",$request->concejo_directivo_id)
                ->update([
                    "cantidad" => $cantidad[0]["cantidad"]+1
                ]);
            }else{
                RegistroPosultacion::create([
                    "user_id" => $request->user_id,
                    "concejo_directivo_id" => $request->concejo_directivo_id,
                    "cantidad" => 1
                ]);
            }
            $mensaje ="Candidato Postulado con exito";
            return view("administrador.administrador",compact("mensaje"));
        }
    }
    //CRUD Concejo directivo
    //vista
    public function concejoDirectivos(){

        $concejoDirectivos = ConcejoDirectivo::all();
        return view("administrador.concejoDirectivos",compact("concejoDirectivos"));

    }


    public function verVotaciones(Request $request){
        
        $fechaVotaciones = FechaVotaciones::where("id",$request->id)->first();
        $concejos = ConcejoDirectivo::all();
    
            $candidatos = Candidato::where("fecha_votacione_id",$fechaVotaciones["id"])
            ->orderBy("concejo_directivo_id")->get();
        

        
        return view("administrador.verVotaciones",compact("fechaVotaciones","concejos"));

    }

    public function resultadoDocente(){
        $concejoId = ConcejoDirectivo::where("nombre","Docente")->first();

        $fechaVotaciones = FechaVotaciones::select("id")
        ->where("concejo_directivo_id",$concejoId["id"])
        ->orderByDesc("id")
        ->first();

        $candidatos = CandidatoDocente::where("fecha_votacione_id",$fechaVotaciones["id"])
        ->orderByDesc("votos")
        ->get();
        return view("administrador.resultadoDocente",compact("candidatos"));

    }

    public function registrarConcejo($mensajeError=null){

        return view("administrador.registrarConcejo",compact("mensajeError"));

    }

    public function guardarConcejo(Request $request){

        if (empty($request->nombre)) {
            $mensaje = "Los campos con (*) son obligatorios";
            return $this->registrarConcejo($mensaje);
        }

        ConcejoDirectivo::create([

            "nombre" => $request->nombre
        ]);

        return redirect("/concejoDirectivos");

    }

    public function editarConcejo(Request $request,$mensajeError=null){

        $concejoDirectivos = ConcejoDirectivo::where("id",$request->id)->first();
        return view("administrador.editarConcejo",compact("concejoDirectivos","mensajeError"));
        

    }

    public function actualizarConcejo(Request $request){

        
        if (empty($request->nombre)) {
            $mensaje = "Los campos con (*) son obligatorios";
            return $this->editarConcejo($request,$mensaje);
        }

        ConcejoDirectivo::where("id",$request->id)->update([

            "nombre" => $request->nombre

        ]);
        
        return redirect("/concejoDirectivos");

    }


    //CRUD de usuarios
    //Registra usuarios
    public function registrar(){

        return view("administrador.registroUsuario");

    }
    //Mostrar todos los usuarios
    public function usuarios(){

        $usuarios = User::where("numeroDocumento","!=",97061707445)->get();
        return view("administrador.usuarios",compact("usuarios"));

    }
    //Eliminar usuarios
    public function eliminarUsuario(Request $request){

        User::where("id",$request->id)->delete();
        return redirect("/usuarios");

    }
    //Mostrar usuario a actualizar
    public function mostrarUsuario(Request $request){

        $usuario = User::where("id",$request->id)->first();

        return view("administrador.mostrarUsuario",compact("usuario"));

    }
    //Actualizar usuario
    public function actualizarUsuario(Request $request){

            // $this->validate($request,[
            //     'name' => ['required', 'string', 'max:255'],
            //     'primerApellido' => ['required', 'string', 'max:255'],
            // 'segundoApellido' => ['required', 'string', 'max:255'],
            // 'tipoDocumento_id' => ['required', 'integer'],
            // 'numeroDocumento' => ['required', 'string', 'max:255'],
            // 'telefono' => ['required', 'string', 'max:255'],
            // 'celular' => ['required', 'string', 'max:255'],
            // 'direccion' => ['required', 'string', 'max:255'],
            // 'ciudad_id' => ['required', 'integer'],
            // 'role_id' => ['required', 'integer'],
            // 'codigoVotacion' => ['required', 'integer'],
            // 'email' => ['required', 'string', 'email', 'max:255'],

            // ]); 
        
        if ($archivo = $request->file('foto')) {
            
            $nombreFoto = $archivo->getClientOriginalName();
            $archivo->move("fotoUsuarios", $nombreFoto);

        }else{
            $foto = User::where("id",$request->id)->first();
            $nombreFoto=$foto["foto"];
        }    


        User::where("id",$request->id)->update([
            'name' => $request->name,
            'primerApellido' => $request->primerApellido,
            'segundoApellido' => $request->segundoApellido,
            'tipoDocumento_id' => $request->tipoDocumento_id,
            'numeroDocumento' => $request->numeroDocumento,
            'telefono' => $request->telefono,
            'celular' => $request->celular,
            'descripcion' => $request->descripcion,
            'direccion' => $request->direccion,
            'ciudad_id' => $request->ciudad_id,
            'codigoVotacion' => $request->codigoVotacion,
            'email' => $request->email,
            'role_id' => $request->role_id,
            'foto' => $nombreFoto,
        ]);

        return redirect("/usuarios");

    }

    //CRUD fecha de votaciones
    //Mostrar formulario
    public function fechaVotacion(){

        return view("administrador.fechaVotacion");

    }

    public function listaFechas(){
        
        $fechas = FechaVotaciones::all();
        return view("administrador.listaFechas",compact("fechas"));

    }
    public function editarFechaVotacion(Request $request,$mensajeError=null){

        $fechaVotaciones = FechaVotaciones::where("id",$request->id)->first();
        return view("administrador.editarFechaVotaciones",compact("fechaVotaciones","mensajeError"));
        

    }
    //Actualizar fecha de votaciones
    public function actualizarFechaVotacion(Request $request){

        $fechaI= explode("/",$request->fechaInicio);
        $horaI = explode("/",$request->horaInicio);
        $fechaInicio = $fechaI[0]." ".$horaI[0];

        $fechaF= explode("/",$request->fechaFinal);
        $horaF = explode("/",$request->horaFinal);
        $fechaFinal = $fechaF[0]." ".$horaF[0];
        
        
        $fechaVotacion = FechaVotaciones::where("id","!=",$request->id)->get();
        foreach ($fechaVotacion as $fecha) {

            if ($fechaInicio.":00"  <= $fecha["fechaFinal"]
                && $fechaInicio.":00" >= $fecha["fechaInicio"]) {
                    
                    $errorFecha = "Esta fecha ya esta asignada para este concejo directivo";
                    return view("administrador.fechaVotacion", compact("errorFecha"));
            }else if ($fechaFinal.":00"  >= $fecha["fechaInicio"]
                    && $fechaFinal.":00" <= $fecha["fechaFinal"]) {
                        
                        $errorFecha = "Esta fecha ya esta asignada para este concejo directivo";
                        return view("administrador.fechaVotacion", compact("errorFecha"));
                }

        }   

        
        if (
            empty($request->fechaInicio) ||
            empty($request->horaInicio)  ||
            empty($request->fechaFinal)  ||
            empty($request->horaFinal)) {
                
            $mensaje = "los campos con (*) son obligatorios";
            return $this->editarFechaVotacion($request,$mensaje);
        }

        date_default_timezone_set('America/Bogota');
        $fechaActual = date("Y-m-d h:i:s");
        FechaVotaciones::where("id",$request->id)->update([

            "fechaActual" => $fechaActual,
            "fechaInicio" => $fechaInicio,
            "fechaFinal" => $fechaFinal,
            
        ]);
        
        $mensaje="Registro guardado con exito";
        return view("administrador.administrador",compact("mensaje"));

    }
    //Guardar Fecha de votaciones
    public function guardarFechaVotacion(Request $request){

        $fechaI= explode("/",$request->fechaInicio);
        $horaI = explode("/",$request->horaInicio);
        $fechaInicio = $fechaI[0]." ".$horaI[0];

        $fechaF= explode("/",$request->fechaFinal);
        $horaF = explode("/",$request->horaFinal);
        $fechaFinal = $fechaF[0]." ".$horaF[0];
        
        
        $fechaVotacion = FechaVotaciones::all();
        foreach ($fechaVotacion as $fecha) {
            
            if(empty($request->fechaInicio) || empty($request->horaInicio)
            || empty($request->fechaFinal || empty($request->horaFinal))){

                    $errorFecha = "No se admiten campos vacios";
                    return view("administrador.fechaVotacion", compact("errorFecha"));

            }else if ($fechaInicio.":00"  >= $fecha["fechaInicio"] 
                && $fechaFinal.":00" <= $fecha["fechaFinal"]) {

                    $errorFecha = "Esta fecha ya esta asignada para este concejo directivo";
                    return view("administrador.fechaVotacion", compact("errorFecha"));

            }else if($fecha["fechaInicio"] >= $fechaInicio.":00"
                    && $fecha["fechaFinal"] <= $fechaFinal.":00"){
                       
                        $errorFecha = "Ya existe una fecha asignada en este rango de fechas";
                        return view("administrador.fechaVotacion", compact("errorFecha"));

            }else if($fecha["fechaInicio"] >= $fechaInicio.":00"
                    && $fechaFinal.":00" <= $fecha["fechaFinal"]){

                        $errorFecha = "Ya existe una fecha asignada en este rango de fechas";
                        return view("administrador.fechaVotacion", compact("errorFecha"));  

            }else if($fechaInicio.":00"  >= $fecha["fechaInicio"]
                    && $fechaInicio.":00"  <= $fecha["fechaFinal"]
                    && $fecha["fechaFinal"] <=  $fechaFinal.":00"){

                        $errorFecha = "Ya existe una fecha asignada en este rango de fechas";
                        return view("administrador.fechaVotacion", compact("errorFecha"));

            }
        }

        

        date_default_timezone_set('America/Bogota');
        $fechaActual = date("Y-m-d h:i:s");
        FechaVotaciones::create([

            "fechaActual" => $fechaActual,
            "fechaInicio" => $fechaInicio,
            "fechaFinal" => $fechaFinal
        ]);

        $fecha = FechaVotaciones::orderByDesc("id")->first();
        $concejos = ConcejoDirectivo::all();
        $votoBlanco = User::where("numeroDocumento",97061707445)->first();
        
        foreach ($concejos as $concejo) {
            Candidato::create([
                "user_id" => $votoBlanco["id"],
                "concejo_directivo_id" => $concejo["id"],
                "fecha_votacione_id" => $fecha["id"],
                "votos" => 0
            ]);
        }
        $mensaje="Registro guardado con exito";
        return view("administrador.administrador",compact("mensaje"));

    }


}
