<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\User;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => ['required', 'string', 'max:255'],
            'primerApellido' => ['required', 'string', 'max:255'],
            'segundoApellido' => ['required', 'string', 'max:255'],
            'carrera_id' => ['required', 'integer'],
            'semestre' => ['required', 'integer'],
            'tipoDocumento_id' => ['required', 'integer'],
            'numeroDocumento' => ['required', 'string', 'max:255'],
            'fechaExpedicion' => ['required', 'date'],
            'telefono' => ['required', 'string', 'max:255'],
            'celular' => ['required', 'string', 'max:255'],
            'direccion' => ['required', 'string', 'max:255'],
            'ciudad_id' => ['required', 'integer'],
            'role_id' => ['required', 'integer'],
            'codigoVotacion' => ['required', 'integer'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
        return User::create([
            'name' => $data['name'],
            'primerApellido' => $data['primerApellido'],
            'segundoApellido' => $data['segundoApellido'],
            'carrera_id' => $data['carrera_id'],
            'semestre' => $data['semestre'],
            'tipoDocumento_id' => $data['tipoDocumento_id'],
            'numeroDocumento' => $data['numeroDocumento'],
            'fechaExpedicion' => $data['fechaExpedicion'],
            'telefono' => $data['telefono'],
            'celular' => $data['celular'],
            'direccion' => $data['direccion'],
            'ciudad_id' => $data['ciudad_id'],
            'codigoVotacion' => $data['codigoVotacion'],
            'email' => $data['email'],
            'role_id' => $data['role_id'],
            'password' => Hash::make($data['password']),
        ]);
    }
}
