<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\CandidatoDocente;
use App\User;
use App\FechaVotaciones;
use App\RegistroVoto;
use App\ConcejoDirectivo;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;


class DocenteController extends Controller
{
    //Se realiza un metodo constructor para autenticar el usuario por medio de un Middleware
    public function __construct(){

                    $this->middleware("Docente");

    }

    //funcion que realiza el llamado de la interfaz principal del Docente

    public function index(){
        
                    return view("docente.docente");

    }

    public function validarCodigo(Request $request){
        
                    $usuario = Auth::user();

                    $datos = [
                        "titulo" => "Codigo de votación", 
                        "contenido" => "$usuario->codigoVotacion es su codigo de votación"
                    ];

                    Mail::send("email.test",$datos,function($mensaje){
                        $usuario = Auth::user();
                        $mensaje->to($usuario['email'],$usuario['name'])
                        ->subject("Codigo de votación");
                    });

                    return view("docente.validarCodigo",compact("request"));

    }

    // Esta funcion permite realizar la votación al docente 

    public function votarDocente(Request $request){
        
                    $usuario = Auth::user();

                    if($usuario->codigoVotacion == $request->codigoVotacion){

                            date_default_timezone_set('America/Bogota');
                            $fechaActual = explode("/",date("Y-m-d h:i:s"));

                            $concejoId = ConcejoDirectivo::where("nombre","docente")->first();
                            FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                            ->update([
                            "fechaActual" => $fechaActual[0],
                            ]);
                    
                            $fecha = FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                            ->where("fechaActual",$fechaActual[0])
                            ->orderByDesc("id")
                            ->first();
                    
                            $votoUsuario = RegistroVoto::where("user_id",$usuario["id"])
                            ->where("fecha_votacione_id",$fecha["id"])
                            ->get();    
                    
                    
                    if (count($votoUsuario)) {
                            $mensajeAlerta = "Usted ya ha votado Gracias!";
                            return view("docente.docente",compact("mensajeAlerta"));
                    }

                    
                    $votos = CandidatoDocente::select("votos")
                    ->where("user_id",$request->user_id)
                    ->where("fecha_votacione_id",$fecha["id"])
                    ->first();
                    
                    CandidatoDocente::where("user_id",$request->user_id)
                    ->where("fecha_votacione_id",$fecha["id"])
                    ->update([
                        "votos" => $votos["votos"]+1,
                    ]);
                    
                    
                    RegistroVoto::create([
                        "user_id" => $usuario["id"],
                        "fecha_votacione_id" => $fecha["id"]
                    ]);
                    
                
                    $mensaje="¡ Voto asignado con exito !";
                    return view("docente.docente",compact("mensaje"));

                    }else{
                            $mensajeError="Codigo de votación invalido";
                            return view("docente.docente",compact("mensajeError"));
                    }     
    }

    public function candidatosDocente(){

                    
                    date_default_timezone_set('America/Bogota');
                    $fechaActual = explode("/",date("Y-m-d h:i:s"));
                    
                    $concejoId = ConcejoDirectivo::where("nombre","docente")->first();
                    
                    FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                    ->update([
                        "fechaActual" => $fechaActual[0],
                    ]);
                    
                    $fecha = FechaVotaciones::where("concejo_directivo_id","1")
                    ->where("fechaActual",$fechaActual[0])
                    ->orderByDesc("id")
                    ->first();

                    $candidatos = CandidatoDocente::all();
                
                    $fechaVotaciones = FechaVotaciones::whereBetween("fechaActual",array($fecha["fechaInicio"],$fecha["fechaFinal"]))
                    ->where("concejo_directivo_id",$concejoId["id"])
                    ->get();
                    
                    return view("docente.candidatosDocente", compact("candidatos","fechaVotaciones"));

    }

    public function postularse(){

        
                    return view("docente.postularDocente");

    }

    public function crearPostulacion(Request $request){
        
                    date_default_timezone_set('America/Bogota');
                    $fechaActual = explode("/",date("Y-m-d h:i:s"));
                    
                    $concejoId = ConcejoDirectivo::where("nombre","docente")->first();

                    FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                    ->update([
                        "fechaActual" => $fechaActual[0],
                    ]);
                
                    $fecha = FechaVotaciones::where("concejo_directivo_id",$concejoId["id"])
                    ->where("fechaActual",$fechaActual[0])
                    ->orderByDesc("id")
                    ->first();

                    $fechaVotaciones = FechaVotaciones::whereBetween("fechaActual",array($fecha["fechaInicio"],$fecha["fechaFinal"]))
                    ->where("concejo_directivo_id",$concejoId["id"])
                    ->get();

                    if (count($fechaVotaciones)) {
                        $this->validate($request,[
                            "perfil" => ["required" , "string"],
                            "user_id" => ["unique:candidato_docentes"],
                            "planGobierno" => ["required" , "string"]
                        ]);
                
                        candidatoDocente::create([
                            "user_id" => $request->user_id,
                            "perfil" => $request->perfil,
                            'trayectoriaUno' => "$request->trayectoriaUno",
                            "trayectoriaDos" => $request->trayectoriaDos,
                            "trayectoriaTres" => $request->trayectoriaTres,
                            "trayectoriaCuatro" => $request->trayectoriaCuatro,
                            "planGobierno" => $request->planGobierno,
                            "fecha_votacione_id" => $fechaVotaciones[0]["id"],
                        ]);
                        
                        $mensaje = "Postulación registrada exitosameente";
                        return view("docente.docente",compact("mensaje"));    

                    }else{

                        $mensajeError = "La fecha de votación ya expiro";
                        return view("docente.docente",compact("mensaje"));

                    }  
        

    }

    public function resultadoDocente(){

                    $concejoId = ConcejoDirectivo::where("nombre","Docente")->first();

                    $fechaVotaciones = FechaVotaciones::select("id")
                    ->where("concejo_directivo_id",$concejoId["id"])
                    ->orderByDesc("id")
                    ->first();

                    $candidatos = CandidatoDocente::where("fecha_votacione_id",$fechaVotaciones["id"])
                    ->orderByDesc("votos")
                    ->get();

                    return view("docente.resultadoDocente",compact("candidatos"));

    }

}
